@@ -8,7 +8,7 @@ pub fn plugin() -> Plugin {
 		info!("Prettifying links...");
 		let files = ir.files.clone();
 		let html_files = files.iter().filter(|(p, _)| match p.extension() {
-			Some(ext) => ext == "html",
+			Some(ext) => ext == "html" && p.file_name().unwrap() != "index.html",
 			None => false,
 		});
 		for (path, file) in html_files {
